%let name=church;
filename odsout 'church_maps';

/*
Do this outside the macro, so you only have to do it once...
*/

libname robsmaps '../democd97';
data mymap; set robsmaps.uscounty (where=(statecode not in ('AK' 'HI'))) /*(where=(density<=1))*/;
/* can't use lower density, because of S1406685,
which unfortunately makes the htm file with hover-text
a bit large and slow to load
*/
run;

/* Annotate state outlines onto the county map */
proc gremove data=mymap out=anno_outline;
by state;
id county;
run;
data anno_outline; set anno_outline; 
by state segment notsorted;
length function color $8;
color='gray55'; style='mempty'; when='a'; xsys='2'; ysys='2';
if first.segment then function='poly';
else function='polycont';
run;


/* -------------------------------------------------------------------- */

%macro church(variable,label);

/* Percent of county population that is this religion */
%let pctvar=&variable.RT;

/* Total number of adherents to this religion */
%let totvar=&variable.AD;

goptions dev=png;
goptions xpixels=800 ypixels=575;
goptions border; 

ODS LISTING CLOSE;
ODS HTML path=odsout body="&variable..htm" 
 (title="&label") 
 style=htmlblue;

goptions ftitle="Albany AMT/bold" ftext="Albany AMT" gunit=pct htitle=4 htext=2.5;
goptions ctext=gray33;

libname datalib "../democd31/";

/* Get the label text for the chosen variable */
proc sql noprint;
create table temp1 as
select label
from dictionary.columns
where libname=%upcase("datalib")
 and memname=%upcase("church_data")
 and upcase(name)=%upcase("&pctvar");
quit; run;

data temp1; set temp1;
label=translate(label," ",",");
label=translate(label," ",";");
label=translate(label," ","'");
label=substr(label,1,index(label,'--')-1);
run;

proc sql noprint;
select label into :mylabel separated by ' ' from temp1;
quit; run;

proc sql noprint;

/* Get the % data */
create table pctdata as
select stcod as state, stateab, ctycod as county, county as county_name, &pctvar/1000 format=percent8.2 as &pctvar
from datalib.church_data
where stateab^='AK' and stateab^='HI' and &pctvar^=0
order by &pctvar desc;

/* Get the total data */
create table totdata as
select stcod as state, stateab, ctycod as county, county as county_name, &totvar format=comma9.0 as &totvar
from datalib.church_data
where stateab^='AK' and stateab^='HI' and &totvar^=0
order by &totvar desc;

quit; run;

/* Add the html mouse-over text */
data pctdata; set pctdata;
length my_html $300;
my_html= 
 'title='||quote(
  trim(left(put(&pctvar,percent7.2)))||' '||trim(left("&mylabel"))||'0d'x||
  trim(left(county_name))||' county, '||trim(left(fipname(state))));
run;

data totdata; set totdata;
length my_html $300;
my_html=
 'title='||quote(
  trim(left(put(&totvar,comma9.0)))||' adherents to '||trim(left("&mylabel"))||'0d'x||
  trim(left(county_name))||' county, '||trim(left(fipname(state))));
run;

pattern1 value=solid color=cxfef0d9;
pattern2 value=solid color=cxfdcc8a;
pattern3 value=solid color=cxfc8d59;
pattern4 value=solid color=cxe34a33;
pattern5 value=solid color=cxb30000;

title1 ls=1.5 link='http://www.google.com/search?&q=&mylabel' "&mylabel";

title2 ls=1.2 "Year 2000 Data from: " 
 link='http://www.thearda.com/Archive/Files/Descriptions/RCMSCY.asp' 
 c=blue "www.TheARDA.com";

legend1 label=(position=bottom j=c f="albany amt/bold" "Percent of population adherent to" j=c "&mylabel") 
 value=(j=center) position=(bottom left) mode=share 
 across=1 order=descending shape=bar(.1in, .1in);

proc gmap data=pctdata map=mymap all anno=anno_outline;
id state county;
choro &pctvar / levels=5 legend=legend1 
 coutline=graybb cempty=grayee
 html=my_html 
 des='' name="&variable";
run;

title c=gray33 "&mylabel Top 10 Counties";
footnote;
proc print data=pctdata (obs=10) noobs label
 style(data)={font_size=11pt}
 style(header)={font_size=11pt};
label county_name='County';
label stateab='State';
label &pctvar='% Of Population';
var county_name stateab &pctvar;
run;

title1 ls=1.5 link='http://www.google.com/search?&q=&mylabel' "&mylabel";

title2 ls=1.2 "Year 2000 Data from: " 
 link='http://www.thearda.com/Archive/Files/Descriptions/RCMSCY.asp' 
 c=blue "www.TheARDA.com";

legend1 label=(position=bottom j=c f="albany amt/bold" "Number of people adherent to" j=c "&mylabel") 
 value=(j=center) position=(bottom left) mode=share 
 across=1 order=descending shape=bar(.1in, .1in);

proc gmap data=totdata map=mymap all anno=anno_outline;
id state county;
choro &totvar / levels=5 legend=legend1 
 coutline=graybb cempty=grayee
 html=my_html 
 des='' name="&variable";
run;

title c=gray33 "&mylabel Top 10 Counties";
footnote;
proc print data=totdata (obs=10) noobs label
 style(data)={font_size=11pt}
 style(header)={font_size=11pt};
label county_name='County';
label stateab='State';
label &totvar='Number of Adherents';
var county_name stateab &totvar;
run;

quit;
ods html close;
ods listing;

%mend;


%church(QUAKE,Friends (Quaker));
%church(CATH,Catholic Church);
%church(UMETH,United Methodist Church);
%church(LDS,Church of Jesus Christ of Latter-day Saints);
%church(MENUS,Mennonite Church USA);
%church(SBC,Southern Baptist Convention);
%church(SEVAD,Seventh-Day Adventist Church);
%church(CHSCH,Churches of Christ);
%church(OLDOA,Old Order Amish);
%church(PRUSA,Presbyterian Church (USA));
/*
*/
